<?
$modname = getparam("mod",PAR_GET,SAN_FLAT);
$myurl="index.php?mod=$modname&amp;file=";
?>

<b>Se sei entrato qui sei un'amministratore</b>! Controlla il file level.php in questa sezione!!
<br><br>
Questa  una sottosezione, anche qui  possibile utilizzare la variabile <b>$myurl</b>.<br>
Il metodo da utilizzare  sempre lo stesso: <a href="<?=$myurl?>paperino">paperino</a>

